%!TeX root = authors-kit.tex
%
% Copyright 2019 Nicola Gigante
%
% Redistribution and use, with or without modification, are permitted provided
% that the following conditions are met:
%
% 1. Redistributions must retain the above copyright notice, this list of
%    conditions and the following disclaimer.
%
% 2. Neither the name of the copyright holder nor the names of its contributors
%    may be used to endorse or promote products derived from this software
%    without specific prior written permission.
%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{overlay}[2019/06/22 OVERLAY workshop LaTeX class file]

\ProcessOptions\relax

%
% We are very simply based on the `article' standard class
%
\LoadClass[10pt,twoside]{article}

% Basic TeX trickery used below
\RequirePackage{etoolbox} % For \appto

%
% Page layout
%
\RequirePackage[a4paper]{geometry}

\geometry{
  hmargin=2.5cm,
  height=22.8cm,
  vcentering
}

%
% Typography
%
\RequirePackage[T1]{fontenc}
\RequirePackage{lmodern}
\RequirePackage[final]{microtype}

\raggedbottom

%
% Title and authors block
%
\RequirePackage{titling}
\RequirePackage[noblocks]{authblk}

\pretitle{\begin{center}\bfseries\LARGE}
\posttitle{\end{center}\vspace{0.5em}}

\setlength\affilsep{2ex}
\newcommand\email[2][ ]{%
  \affil[#1]{{\normalsize\texttt{#2}}}%
}

% We print no date
\date{}
\renewcommand\date[1]{}
\predate{}
\postdate{}

%
% Copyright note
%
\newcommand\thecopyrightauthors{%
  \ClassError{overlay}{%
    Please specify the authors copyright note with
    \string\copyrightauthors{...}%
  }
}
\newcommand\copyrightauthors[1]{%
  \renewcommand\thecopyrightauthors{#1}%
}

\appto\maketitle{%
  \begingroup
  \let\thefootnote\relax
  \footnotetext{%
    \parbox{\textwidth}{%
      \vspace{1ex}%
      Copyright \copyright\ \the\year\ \thecopyrightauthors\\
      Space reserved for further notes in the final proceedings\\~
    }%
  }%
  \endgroup
}

%
% Abstract
%
\RequirePackage{abstract}
\setlength\absleftindent{5em}
\setlength\absrightindent{5em}
\setlength\abstitleskip{0pt}
\renewcommand\abstractnamefont{\normalfont\bfseries}
\renewcommand\abstracttextfont{\normalfont}

%
% Running heads
%
\RequirePackage{titleps}

\newcommand\therunningauthors{\thecopyrightauthors}
\newcommand\therunningtitle{\thetitle}

\newpagestyle{main}{
  \sethead[\thepage][][\therunningauthors] % even
          {\therunningtitle}{}{\thepage} % odd
}
\pagestyle{main}

\newcommand\runningauthors[1]{%
  \renewcommand\therunningauthors{#1}%
}

\newcommand\runningtitle[1]{%
  \renewcommand\therunningtitle{#1}%
}

%
% Customization of optional packages
%
\PassOptionsToPackage{capitalise,nameinlink,noabbrev}{cleveref}
